==> knowledgegraph-1.0-20250813.100053-3-sources.jar: com/digiwin/athena/knowledgegraph/configuration/AthenaRabbitMQConfig.java <==
package com.digiwin.athena.knowledgegraph.configuration;

import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.core.AcknowledgeMode;
import org.springframework.amqp.rabbit.annotation.EnableRabbit;
import org.springframework.amqp.rabbit.config.SimpleRabbitListenerContainerFactory;
import org.springframework.amqp.rabbit.connection.CachingConnectionFactory;
import org.springframework.amqp.rabbit.connection.ConnectionFactory;
import org.springframework.amqp.rabbit.core.RabbitAdmin;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.autoconfigure.EnableAutoConfiguration;
import org.springframework.boot.autoconfigure.amqp.RabbitAutoConfiguration;
import org.springframework.boot.autoconfigure.amqp.RabbitProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Import;
import org.springframework.context.annotation.Primary;

/**
 * MDC的rabbit,用于接收mdc发送的元数据信息，virtualhost与Athena用的不一致
 */
@Configuration
@Slf4j
@EnableRabbit
//@Import(RabbitProperties.class)
public class AthenaRabbitMQConfig {

    {
        System.out.println("========AthenaRabbitMQConfig init========");
    }

//    @Autowired
//    private RabbitProperties properties;

    @Value("${spring.rabbitmq.addresses}")
    private String addresses;

    @Bean("connectionFactory")
    @Primary
    public ConnectionFactory connectionFactory(){
        CachingConnectionFactory connectionFactory = new CachingConnectionFactory();

        RabbitProperties properties = new RabbitProperties();
        properties.setAddresses(addresses);

        connectionFactory.setHost(properties.determineHost());
        connectionFactory.setPort(properties.determinePort());
        connectionFactory.setUsername(properties.determineUsername());
        connectionFactory.setPassword(properties.determinePassword());
        connectionFactory.setVirtualHost(properties.determineVirtualHost());
        return connectionFactory;
    }


    @Bean(name="amqpAdmin")
    @Primary
    public RabbitAdmin amqpAdmin() {
        return new RabbitAdmin(connectionFactory());
    }

    @Bean(name="rabbitTemplate")
    @Primary
    public RabbitTemplate rabbitTemplate(@Qualifier("connectionFactory") ConnectionFactory connectionFactory){
        RabbitTemplate rabbitTemplate = new RabbitTemplate(connectionFactory);
        return rabbitTemplate;
    }

    @Bean(name="rabbitListenerContainerFactory")
    @Primary
    public SimpleRabbitListenerContainerFactory rabbitListenerContainerFactory(@Qualifier("connectionFactory") ConnectionFactory connectionFactory) {
        SimpleRabbitListenerContainerFactory factory = new SimpleRabbitListenerContainerFactory();
        factory.setConnectionFactory(connectionFactory);
        factory.setAcknowledgeMode(AcknowledgeMode.MANUAL);

        return factory;
    }

}

==> knowledgegraph-1.0-20250827.021215-5-sources.jar: com/digiwin/athena/knowledgegraph/configuration/AthenaRabbitMQConfig.java <==
package com.digiwin.athena.knowledgegraph.configuration;

import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.core.AcknowledgeMode;
import org.springframework.amqp.rabbit.annotation.EnableRabbit;
import org.springframework.amqp.rabbit.config.SimpleRabbitListenerContainerFactory;
import org.springframework.amqp.rabbit.connection.CachingConnectionFactory;
import org.springframework.amqp.rabbit.connection.ConnectionFactory;
import org.springframework.amqp.rabbit.core.RabbitAdmin;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.autoconfigure.amqp.RabbitProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

/**
 * MDC的rabbit,用于接收mdc发送的元数据信息，virtualhost与Athena用的不一致
 */
@Configuration
@Slf4j
@EnableRabbit
//@Import(RabbitProperties.class)
public class AthenaRabbitMQConfig {

    {
        System.out.println("========AthenaRabbitMQConfig init========");
    }

//    @Autowired
//    private RabbitProperties properties;

    @Value("${spring.rabbitmq.addresses}")
    private String addresses;

    @Bean("kgconnectionFactory")
  //  @Primary
    public ConnectionFactory kgconnectionFactory(){
        CachingConnectionFactory connectionFactory = new CachingConnectionFactory();

        RabbitProperties properties = new RabbitProperties();
        properties.setAddresses(addresses);

        connectionFactory.setHost(properties.determineHost());
        connectionFactory.setPort(properties.determinePort());
        connectionFactory.setUsername(properties.determineUsername());
        connectionFactory.setPassword(properties.determinePassword());
        connectionFactory.setVirtualHost(properties.determineVirtualHost());
        return connectionFactory;
    }


    @Bean(name="kgamqpAdmin")
   // @Primary
    public RabbitAdmin kgamqpAdmin() {
        return new RabbitAdmin(kgconnectionFactory());
    }

    @Bean(name="kgrabbitTemplate")
   // @Primary
    public RabbitTemplate kgrabbitTemplate(@Qualifier("kgconnectionFactory") ConnectionFactory connectionFactory){
        RabbitTemplate rabbitTemplate = new RabbitTemplate(connectionFactory);
        return rabbitTemplate;
    }

    @Bean(name="kgrabbitListenerContainerFactory")
   // @Primary
    public SimpleRabbitListenerContainerFactory kgrabbitListenerContainerFactory(@Qualifier("kgconnectionFactory") ConnectionFactory connectionFactory) {
        SimpleRabbitListenerContainerFactory factory = new SimpleRabbitListenerContainerFactory();
        factory.setConnectionFactory(connectionFactory);
        factory.setAcknowledgeMode(AcknowledgeMode.MANUAL);

        return factory;
    }

}
